==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/bean/InvoicedetialEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发票管理子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_invoicedetial")
public class InvoicedetialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 
    @TableField(value="bill_code")
    private String billCode; // 销售单编号
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="receivables_date")
    private Date receivablesDate; // 记账日期
    @TableField(value="invoice_money")
    private BigDecimal invoiceMoney; // 应开金额
    @TableField(value="received_money")
    private BigDecimal receivedMoney; // 本单已开金额
    @TableField(value="other_received_money")
    private BigDecimal otherReceivedMoney; // 其他单已开金额
    @TableField(value="uncollected_money")
    private BigDecimal uncollectedMoney; // 未收金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="sale_id")
    private Long saleId; // 销售单id
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Date getReceivablesDate() {
        return receivablesDate;
    }

    public void setReceivablesDate(Date receivablesDate) {
        this.receivablesDate = receivablesDate;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getSaleId() {
        return saleId;
    }

    public void setSaleId(Long saleId) {
        this.saleId = saleId;
    }
    
}

==> ejc-sale-impl-3.0.0-20220728.054232-187-sources.jar: com/ejianc/business/sale/bean/InvoicedetialEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发票管理子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_invoicedetial")
public class InvoicedetialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 
    @TableField(value="bill_code")
    private String billCode; // 销售单编号
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="receivables_date")
    private Date receivablesDate; // 记账日期
    @TableField(value="receivables_time")
    private String receivablesTime; // 记账日期汇总
    @TableField(value="invoice_money")
    private BigDecimal invoiceMoney; // 应开金额
    @TableField(value="received_money")
    private BigDecimal receivedMoney; // 本单已开金额
    @TableField(value="other_received_money")
    private BigDecimal otherReceivedMoney; // 其他单已开金额
    @TableField(value="uncollected_money")
    private BigDecimal uncollectedMoney; // 未收金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="sale_id")
    private Long saleId; // 销售单id
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Date getReceivablesDate() {
        return receivablesDate;
    }

    public void setReceivablesDate(Date receivablesDate) {
        this.receivablesDate = receivablesDate;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getReceivedMoney() {
        return receivedMoney;
    }

    public void setReceivedMoney(BigDecimal receivedMoney) {
        this.receivedMoney = receivedMoney;
    }
    public BigDecimal getOtherReceivedMoney() {
        return otherReceivedMoney;
    }

    public void setOtherReceivedMoney(BigDecimal otherReceivedMoney) {
        this.otherReceivedMoney = otherReceivedMoney;
    }
    public BigDecimal getUncollectedMoney() {
        return uncollectedMoney;
    }

    public void setUncollectedMoney(BigDecimal uncollectedMoney) {
        this.uncollectedMoney = uncollectedMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getSaleId() {
        return saleId;
    }

    public void setSaleId(Long saleId) {
        this.saleId = saleId;
    }

    public String getReceivablesTime() {
        return receivablesTime;
    }

    public void setReceivablesTime(String receivablesTime) {
        this.receivablesTime = receivablesTime;
    }
}
